Documentation
¶
Overview ¶
Package fluentforwardexporter exports log events using the Fluent Forward protocol
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewFactory ¶
NewFactory creates a factory for the fluentforward exporter.
Types ¶
type Config ¶
type Config struct {
TCPClientSettings `mapstructure:",squash"` // squash ensures fields are correctly decoded in embedded struct.
// RequireAck enables the acknowledgement feature.
RequireAck bool `mapstructure:"require_ack"`
// The Fluent tag parameter used for routing
Tag string `mapstructure:"tag"`
// CompressGzip enables gzip compression for the payload.
CompressGzip bool `mapstructure:"compress_gzip"`
// DefaultLabelsEnabled is a map of default attributes to be added to each log record.
DefaultLabelsEnabled map[string]bool `mapstructure:"default_labels_enabled"`
QueueBatchConfig configoptional.Optional[exporterhelper.QueueBatchConfig] `mapstructure:"sending_queue"`
configretry.BackOffConfig `mapstructure:"retry_on_failure"`
}
Config defines configuration for fluentforward exporter.
type Endpoint ¶
type Endpoint struct {
// TCPAddr is the address of the server to connect to.
TCPAddr string `mapstructure:"tcp_addr"`
// Controls whether to validate the tcp address.
ValidateTCPResolution bool `mapstructure:"validate_tcp_resolution"`
}
Endpoint defines the address of the server to connect to.
type TCPClientSettings ¶
type TCPClientSettings struct {
// Endpoint to send logs to.
Endpoint `mapstructure:"endpoint"`
// Connection Timeout parameter configures `net.Dialer`.
ConnectionTimeout time.Duration `mapstructure:"connection_timeout"`
// ClientConfig struct exposes TLS client configuration.
ClientConfig configtls.ClientConfig `mapstructure:"tls"`
SharedKey string `mapstructure:"shared_key"`
}
TCPClientSettings defines common settings for a TCP client.
Click to show internal directories.
Click to hide internal directories.